@@ -91,7 +91,7 @@ get_flows <- function(geography, variables = NULL, breakdown = NULL,
   if (Sys.getenv('CENSUS_API_KEY') != '') {
     key <- Sys.getenv('CENSUS_API_KEY')
   } else if (is.null(key)) {
-    stop('A Census API key is required. Obtain one at http://api.census.gov/data/key_signup.html, and then supply the key to the `census_api_key` function to use it throughout your tidycensus session.')
+    stop('A Census API key is required. Obtain one at http://api.census.gov/data/key_signup.html, and then supply the key to the `census_api_key()` function to use it throughout your tidycensus session.')
   }
 
   if (geography %in% c("cbsa", "msa", "metropolitan statistical area")) {
