@@ -71,10 +71,15 @@ get_pums <- function(variables = NULL,
 
   } else if (is.null(key)) {
 
-    stop('A Census API key is required.  Obtain one at http://api.census.gov/data/key_signup.html, and then supply the key to the `census_api_key` function to use it throughout your tidycensus session.')
+    stop('A Census API key is required.  Obtain one at http://api.census.gov/data/key_signup.html, and then supply the key to the `census_api_key()` function to use it throughout your tidycensus session.')
 
   }
 
+  # Account for missing PUMAs in 2008-2012 through 2011-2015 ACS samples
+  if (year %in% 2012:2015 && survey == "acs5" && (!is.null(puma) || "PUMA" %in% variables)) {
+    stop("PUMAs are not available for end-years between 2012 and 2015 due to inconsistent PUMA boundary definitions.", call. = FALSE)
+  }
+
 
   # Allow users to get all states by specifying "all"
   # To avoid large data timeout errors, iterate through the states instead.
